.. title:: FIAT


========================================
FIAT: FInite element Automatic Tabulator
========================================

FIAT is a Python package for automatic generation of finite element
basis functions. It is capable of generating finite element basis
functions for a wide range of finite element families on simplices
(lines, triangles and tetrahedra), including the Lagrange elements,
and the elements of Raviart-Thomas, Brezzi-Douglas-Marini and Nedelec.
It is also capable of generating tensor-product elements and a number
more exotic elements, such as the Argyris, Hermite and Morley
elements.

FIAT is part of the FEniCS Project.

For more information, visit http://www.fenicsproject.org.


Documentation
=============

.. toctree::
   :titlesonly:
   :maxdepth: 1

   installation
   manual
   API reference <api-doc/FIAT>
   releases

[FIXME: These links don't belong here, should go under API reference somehow.]

* :ref:`genindex`
* :ref:`modindex`
